function [predut,hthat,sq_hthat_mean,sq_sum_hthat] = filterswarchbetalev(y,lags,eta,alpha,gamma,xi,beta,steps);
% 
% function call: predut = filterswarchbetalev(y,lags,eta,alpha,gamma,xi,beta);
%
% INPUT:
% y     time series, (nx1) vector
% lags  number of lagged dependent variables
% eta   fixed value transition matrix (kxk), rows must be probability vectors
% alpha  fixed values  (mx1)
% gamma  fixed values  for changing variances (kx1)
% xi     fixed value  for leverage parameter
% beta   fixed value for constant and lagged dep. variables
% steps  forcasting steps
%
% OUTPUT:
% simulated values:
% predut, prediction error
% hthat, steps-step ahead predicted ht (volatility squared)
% sq_hthat_mean, mean volatility over steps-step forecasting period
% 
% Authors: Sylvia Kaufmann

%rand('state',987654321);

n=size(y,1);
index=[];for i=1:lags;index=[index;lags-i+1:n-i];end;index=index';
Z=[ones(n-lags,1) y(index)];
y=y(lags+1:end);

nst=size(eta,1);
pini=ones(nst,1)/nst;

% number of states
m=size(alpha,1);
nobs = size(y,1)+1;
states = [1:nst]';
[fvpred sp] = predfiltvertbetalev(y,Z,eta,pini,alpha,gamma,xi,beta);
yhat=Z*beta;
u=y-Z*beta;    

m=size(alpha,1);n=size(u,1);lags=size(Z,2);
index=[];for i=1:m;index=[index;m-i+1:n-i];end;index=index';
U=u(index).^2;
dt=(u(m:end-1)<=0.0).*u(m:end-1).^2;
       
ht=gamma(:,ones(1,n-m))'+U*alpha(:,ones(1,nst))+dt*xi(ones(1,nst));
       
et=y-yhat; 
vt=et(end-size(ht,1)+1:end,ones(1,nst))./(ht.^0.5);
       
       
predut=(1+(erf(vt/sqrt(2))))/2;
       
       
predut=sum(predut.*fvpred(end-size(ht,1)+1:end,:),2);
hthat=fvpred(end-size(ht,1)+1:end,:)*gamma+U*alpha+dt*xi;
hthat_1step=hthat;

fvpred=fvpred(end-size(ht,1)+1:end,:);
htlag=U;
sq_hthat_mean=sqrt(hthat);
sum_hthat=hthat;

y_abs=abs(y(1:end-steps+1));
if steps>1;
 for i=2:steps;
    y_abs=y_abs+abs(y(i:end-steps+i));
 end
 y_abs=y_abs./steps
end

for j=1:steps-1
    htlag=[hthat htlag(:,1:end-1)];
    hthat= fvpred*eta^j*gamma + htlag*[alpha+[xi/2;zeros(m-1,1)]];
    sq_hthat_mean=sq_hthat_mean+sqrt(hthat);
    sum_hthat=sum_hthat+hthat;
end


sq_hthat_mean=sq_hthat_mean./steps;
sq_sum_hthat=sqrt(sum_hthat./steps);
% if steps>1
% fvpred=fvpred(end-size(ht,1)+1:end,:);
% gamma_hat=zeros(size(hthat,1),steps);
% gamma_hat(:,1)=fvpred*gamma;
% wt_gamma=zeros(size(gamma_hat,1)-steps+1,size(gamma_hat,2)-1);
% 
% Amat=[alpha(1)+0.5*xi alpha(2:end)'; eye(m-1) zeros(m-1,1)];
% for i=2:steps
%    gamma_hat(i:end,i)=fvpred(1:end-i+1,:)*eta^(i-1)*gamma;
%    %wt_gamma(:,i-1) =[[gamma_hat(i:end-steps+i,i) zeros(size(wt_gamma,1),m-1)]*Amat'^(steps-i)]*[1;zeros(m-1,1)];
%    wt_gamma(:,i-1) =[[gamma_hat(i:end-steps+i,i) zeros(size(wt_gamma,1),m-1)]*Amat'^(steps-i)]*[ones(m,1)/m]; %mean vol. over forecast horizon
% end
% 
% index=[];for i=0:m-2;index=[index;m-i+1:n-i];end;index=index';
% U_prog=u(index).^2;
% 
% x_prog=[hthat U_prog(end-size(hthat,1)+1:end,:)];
% 
% 
% hthat=x_prog*Amat'^(steps-1)*[ones(m,1)/m];
% hthat=hthat(end-size(wt_gamma,1)-steps+2:end-steps+1,:)+sum(wt_gamma,2);
% end