function [betasim,gammasim,xisim,alphasim,etasim,etapost,betapostm,betapostchol,archpostm,archpostchol,sstsim,accag,accagb,irejsum,loglik] = mcmcswarchbetalevdirmix(y,lags,eta,alpha,gamma,xi,beta,e0,...
                                                                                             alxi0,prgamma,prbem,prbeinf,it0,it,rth);
% [betasim,gammasim,xisim,alphasim,etasim,htlow,htup,htmean,etapost,betapostm,betapostchol,archpostm,archpostchol,prob,accag,accagb,irejsum,loglik] = mcmcswarchbetalevdirmix(y,lags,eta,alpha,gamma,xi,beta,e0,...
%                                                                                             alxi0,prgamma,prbem,prbeinf,it0,it);
% 
% function call: [betasim,gammasim,xisim,alphasim,etasim,etapost,prob,accag,accagb,irejsum,loglik] = mcmcswarchbetalev(y,lags,eta,alpha,gamma,xi,beta,e0,pralm,pralinf,prgamma,it0,it)
%
% INPUT:
% y     time series, (nx1) vector
% lags  number of lagged dependent variables
% eta   initial transition matrix (kxk), rows must be probability vectors
% alpha  initial values (mx1)
% gamma  initial values for changing variances (kx1)
% xi     initial value for leverage parameter
% beta   initial value for constant and lagged dep. variables
% e0    prior on transition probabilities (kxk)
% alxi0 prior on alpha and xi/2: Dirichlet(a_1,...,a_m,x,a_m+1) NEU
% prgamma prior on changing variances (kx2)
% it    number of iterations
% it0   number of iterations discarded
%
% OUTPUT:
% simulated values:
% [betasim,gammasim,xisim,alphasim,etasim,etapost,prob,accag,accagb,irejsum,loglik]
%  beta,gamma,leverage,alpha,trans.prob.,par of posterior for trans.prob.,prob of being in resp. state,
%  acceptance rate for alpha, for beta, rejection rate for alpha,log likelihood
% 
% Authors: Syliva Frhwirth, Sylvia Kaufmann

%  permutation
%perm=1; %identifiability constraint
perm=2; %random permutation sampling
cf=0;  %schalter fr berechnung der model likelihood: 1 nach der candidates formula
%                                                     0 bridge sampling
MMC=1000; % anzhal der summanden der mixture q density beim bridge sampling
mmc=simuni(it-it0,MMC);

itr=sum(~mod([it0+1:it],rth)); %number of retained draws
sit=1;

rand('state',0);
randn('state',0);

n=size(y,1);
index=[];for i=1:lags;index=[index;lags-i+1:n-i];end;index=index';
Z=[ones(n-lags,1) y(index)];
y=y(lags+1:end);

nst=size(eta,1);
pini=ones(nst,1)/nst;

% number of states
m=size(alpha,1);
n = size(y,1)+1;
states = 1:nst;
sstsim = zeros(nst*(nst>1),n,itr)~=0;
sst=ones(1,n);
% htlow=zeros(ceil((it-it0)*0.025),n-m-1);
% htup=zeros(ceil((it-it0)*0.025),n-m-1);
% htmean=zeros(1,n-m-1);
etasim=zeros(nst*(nst>1),nst,itr);
etapost=zeros(nst*(nst>1),nst,cf*(itr)+(1-cf)*MMC);
betapostm=zeros(lags+1,(1-cf)*MMC+cf);
betapostchol=zeros(lags+1,lags+1,(1-cf)*MMC+cf);
archpostm=zeros(m+nst+1,(1-cf)*MMC+cf);
archpostchol=zeros(m+nst+1,m+nst+1,(1-cf)*MMC+cf);

alphasim=zeros(m,itr);
gammasim=zeros(nst,itr);
xisim=zeros(1,itr);
betasim=zeros(lags+1,itr);
irejsum=zeros(m+nst+1,1);
accag=0;
accagb=0;
% prob(1:nst,1:n) = 0;
loglik=zeros(itr,1);

pi=perms(1:nst);
nmix=size(pi,1);
prgamma1=zeros(nst,2,nmix);

for j = 1:it
    for ml=1:nmix
        prgamma1(:,:,ml)=prgamma(pi(ml,:),:);
    end

    if any([1:1000:it]==j)
        j
    end
   
    [fv sp] = filtvertbetalev(y,Z,eta,pini,alpha,gamma,xi,beta);
    if ~mod((j-1),rth)
        loglik(sit)=sp;
    end;
    if nst>1
        sst = simstate(fv,eta);

        [eta cnt] = simtrans(nst,sst(1+m:end),e0,1.);
    end

    %   [alpha gamma xi irej acc]=simarchlevparinfodir(y-Z*beta,eta,sst,alpha,gamma,xi,alxi0,prgamma);

    [alpha gamma xi irej acc muarch prvarch crwarch]=simarchlevparinfodirmix(y-Z*beta,eta,sst,alpha,gamma,xi,alxi0,prgamma1,nmix);

    [beta accb mubeta prvbeta crwbeta ht]=simbetalevparinfo(y,Z,eta,sst,alpha,gamma,xi,beta,prbem,prbeinf);
    if j>it0
        accag=accag+acc;irejsum=irejsum+irej;
        accagb=accagb+accb;
    end

    if perm==1 %identifiability constraint
        [gamma si] = sort(gamma);

        [si1,ssort]=sort(si);  %NEU
        sst = ssort(sst)';   %NEU

        % sst = si(sst)';   %ALT
        eta = eta(si,si);
        if nst>3;
            [etaneu si] = sort([eta(3,3) eta(4,4)]);
            si=[1 2 si(1)+2 si(2)+2];
            %[etaneu si] = sort([eta(1,1) eta(2,2) eta(3,3)]);
            %si=[si(2) si(3) si(1) 4];
            gamma=gamma(si);
            %  sst=si(sst);   %ALT

            [si1,ssort]=sort(si);  %NEU
            sst = ssort(sst);   %NEU

            eta=eta(si,si);
        end;
    end
    if perm==2  %random permuation
        si = randperm(nst);
        gamma=gamma(si);
        prgamma=prgamma(si,:);  %momente der prior werden mitpermutiert
        eta = eta(si,si);
        [si1,ssort]=sort(si);  %NEU
        sst = ssort(sst);   %NEU
    end
    %sstsim(:,j) = sst';
    if j>it0
        if ~mod(j,rth)
            if nst>1
            etasim(:,:,sit) = eta;
            if cf==1
                etapost(:,:,sit)=cnt;
            end
            end
            alphasim(:,sit)=alpha;
            gammasim(:,sit)=gamma;
            xisim(1,sit)=xi;
            betasim(:,sit)=beta;
            if nst>1
            ind = sst(ones(1,nst),:) == states(ones(1,n),:)';
            sstsim(:,:,sit) = ind;
            end
            sit=sit+1;
        end
        %         prob = prob + ind;
        %          if j-it0<=size(htlow,1);
        %             htlow(j-it0,:)=ht;
        %             htup(j-it0,:)=ht;
        %             if j-it0==size(htlow,1);
        %                htlow=sort(htlow);
        %                htup=sort(htup);
        %             end;
        %           end;
        %           if j-it0>size(htlow,1);
        %           indlow=find(ht<=htlow(end,:));
        %           indup=find(ht>=htup(1,:));
        %           htlow(end,indlow)=ht(indlow);
        %           htup(1,indup)=ht(indup);
        %           hth=sort(htlow(:,indlow));
        %           htlow(:,indlow)=hth;
        %           hth=sort(htup(:,indup));
        %           htup(:,indup)=hth;
        %           end;
        %          htmean=htmean+ht;
    jm=find(mmc==(j-it0));
    if and(cf==0,any(jm))
        %          if j > max(it0,it-MMC)
        %            jm=j-max(it0,it-MMC);
        if nst>1;
        etapost(:,:,jm)=cnt(:,:,ones(length(jm),1));
        end
        betapostm(:,jm)=mubeta(:,ones(length(jm),1));
        betapostchol(:,:,jm)=crwbeta(:,:,ones(length(jm),1));
        archpostm(:,jm)=muarch(:,ones(length(jm),1));
        archpostchol(:,:,jm)=crwarch(:,:,ones(length(jm),1));
        %          end
    end
    end




end
if nst>1
    [fv loglik(end)] = filtvertbetalev(y,Z,etasim(:,:,end),pini,alphasim(:,end),gammasim(:,end),xisim(:,end),betasim(:,end));
elseif nst==1
    [fv loglik(end)] = filtvertbetalev(y,Z,eta,pini,alphasim(:,end),gammasim(:,end),xisim(:,end),betasim(:,end));
end
accag=accag/(it-it0);irejsum=irejsum/(it-it0);
accagb=accagb/(it-it0);
% prob = prob/(it-it0);
% htmean=htmean/(it-it0);
