function [vola_ser1,stat1,vola_ser2,stat2]=bayesvola_for_eval(ret_ser,swfile,gafile,L,for_hor,for_steps,time_hor,impl_vol);
%[vola_ser1,stat1]=vola_for_eval(y,259,5,[0.02 0.08 0.90 0.07 0.03]',2.248,25,dax_00(:,2)/sqrt(252));
%259, da schaetzsample die beobachtung vom 3.1.2000 auch beinhaltet; laesst man sie weg, ist der for_hor=260
%[vola_ser1,stat1]=vola_for_eval(y,521,5,25,dax_01(:,2)/sqrt(252));
%function to evaluate volatility series relative to realized volatility
% input	ret_ser= return series, including forecasting period
%           swfile = file name with MCMC draws of switching ARCH model
%           gafile = file name with MCMC draws of GARCH model
%           L = number of MCMC draws used to compute forecasts
%			for_hor= forecasting horizon, the last s values of ret_ser
%			for_steps= n_step forecasts
%			time_hor= window for estimating constant volatility
%			impl_vol=series for implied volatility

% output	vola_ser1= for_steps-step volatility forecasts: SWARCH, GARCH, const. vol., realized vola, implied vola, SWARCH(sampled S_t) 
%           vola_ser2= overall volatility forecasts (sqrt of average volatility)
%			stat1= criteria to evaluate for_steps-step forecasts of SWARCH, GARCH, const. vol., implied vola (by column), SWARCH(sampled S_t) 
%					RMSE, RMSLE, MAPE (by row) rel to realized volatility
%					RMSE, RMSLE, MAPE (by row) rel to implied volatility
%           stat2= criteria of overall volatility forecasts

eff_for=for_hor-for_steps+1; %eff. forecast horizon
vola_ser1=zeros(eff_for,6,L);
vola_ser2=zeros(eff_for,6,L);
stat1=zeros(3,5,L);
stat2=zeros(3,5,L);
vola_garch=zeros(for_hor,1);

load(swfile)
permutieren;
% abschneiden;
MMC=size(etasim,3);
if L<MMC;
    % zufllige auswahl der MCMC simulationen
    u = simuni(MMC,L);
    etamc=etasim(:,:,u);
    alphamc=alphasim(:,u);
    gammamc=gammasim(:,u);
    betamc=betasim(:,u);
    ximc=xisim(:,u);
end
clear *sim* y loglik

load(gafile);
MMC=size(alphasim,2);
if L<=MMC;
    % zufllige auswahl der MCMC simulationen
    u = simuni(MMC,L);
    galphamc=alphasim(:,u);
    ggammamc=gammasim(:,u);
    gbetamc=betasim(:,u);
end
clear *sim* *post*
    
y=ret_ser;

n=size(y,1);
index=[];for i=1:lags;index=[index;lags-i+1:n-i];end;index=index';
Z=[ones(n-lags,1) y(index)];
y=y(lags+1:end);

for j=1:L
    %vola for SWARCH
    [predut,hthat,sq_hthat,sq_sum_hthat,htcond,sq_htcond_mean,sq_sum_htcond] = ... 
                         filterswarchbetalev_bayes(y,Z,etamc(:,:,j),alphamc(:,j),gammamc(:,j),ximc(:,j),betamc(:,j),for_steps);
    vola_ser1(:,1,j)=sqrt(hthat(end-for_hor+1:end-(for_steps-1)));
    vola_ser2(:,1,j)=sq_sum_hthat(end-for_hor+1:end-(for_steps-1));
    vola_ser1(:,6,j)=sqrt(htcond(end-for_hor+1:end-(for_steps-1)));
    vola_ser2(:,6,j)=sq_sum_htcond(end-for_hor+1:end-(for_steps-1));

    
    %vola for GARCH 
    [ghthat,sq_ghthat,sq_sum_ghthat] = garchforecast_bayes(y,Z,qu,galphamc(:,j),ggammamc(:,j),gbetamc(:,j),for_steps);
    vola_ser1(:,2,j)=sqrt(ghthat(end-for_hor+1:end-(for_steps-1)));
    vola_ser2(:,2,j)=sq_sum_ghthat(end-for_hor+1:end-(for_steps-1));

end


%constant volatility forecast
ysq=y(end-for_hor-time_hor+1:end-for_steps).^2;
for i=1:eff_for
%    vola_ser1(i,3)=sum(sqrt(ysq(i:time_hor+i-1)))/time_hor;
   vola_ser1(i,3,:)=sqrt((sum(ysq(i:time_hor+i-1))/time_hor))*ones(1,L);
   vola_ser2(i,3,:)=sqrt((sum(ysq(i:time_hor+i-1))/time_hor))*ones(1,L);
end


%realized volatility and implied volatility
y_abs=abs(y(end-eff_for-for_steps+2:end-for_steps+1));
y_sq=y(end-eff_for-for_steps+2:end-for_steps+1).^2;
sum_impl_vol=impl_vol(end-eff_for-for_steps+2:end-for_steps+1).^2;
if for_steps>1;
 for i=2:for_steps;
    y_abs=y_abs+abs(y(end-eff_for-for_steps+i+1:end-for_steps+i));
    y_sq=y_sq+y(end-eff_for-for_steps+i+1:end-for_steps+i).^2;
%     sum_impl_vol=sum_impl_vol+impl_vol(end-eff_for-for_steps+i+1:end-for_steps+i).^2;
 end
end

mean_impl_vol=impl_vol(end-eff_for-for_steps+2:end-for_steps+1);
% if for_steps>1;
%  for i=2:for_steps;
%     mean_impl_vol=mean_impl_vol+impl_vol(end-eff_for-for_steps+i+1:end-for_steps+i);
%  end
% end


% vola_ser1(:,4)=y_abs/for_steps;
vola_ser1(:,4,:)=kron(ones(1,L),sqrt(y(end-eff_for+1:end).^2));
vola_ser2(:,4,:)=kron(ones(1,L),sqrt(y_sq./for_steps));

index=vola_ser1(:,4,1)>0;
index2=vola_ser2(:,4,1)>0;

%vola_ser1(:,5)=mean_impl_vol/for_steps;
vola_ser1(:,5,:)=kron(ones(1,L),mean_impl_vol);
vola_ser2(:,5,:)=kron(ones(1,L),sqrt(sum_impl_vol));


%RMSE,RMSLE,MAPE rel to realized volatility
stat1(1,:,:)= sqrt(sum([vola_ser1(index,[1:3 5 6],:)-vola_ser1(index,[4*ones(1,5)],:)].^2,1)./sum(index));
stat1(2,:,:)= sqrt(sum([log(vola_ser1(index,[1:3 5 6],:))-log(vola_ser1(index,[4*ones(1,5)],:))].^2,1)./sum(index));
stat1(3,:,:)= sum(abs([vola_ser1(index,[1:3 5 6],:)-vola_ser1(index,[4*ones(1,5)],:)])./(vola_ser1(index,[4*ones(1,5)],:)),1)./sum(index);
%RMSE,RMSLE,RMSPE rel to implied volatility
%stat1(4,:)= sqrt(sum([vola_ser1(:,1:3)-squeeze(vola_ser1(:,5,ones(1,3)))].^2,1)/eff_for);
%stat1(5,:)= sqrt(sum([log(vola_ser1(:,1:3))-log(squeeze(vola_ser1(:,5,ones(1,3))))].^2,1)/eff_for);
%stat1(6,:)= sqrt(sum(([vola_ser1(:,1:3)-squeeze(vola_ser1(:,5,ones(1,3)))].^2)./(squeeze(vola_ser1(:,5,ones(1,3))).^2),1)/eff_for);

%RMSE,RMSLE,MAPE rel to realized volatility: overall volatility
stat2(1,:,:)= sqrt(sum([vola_ser2(index,[1:3 5 6],:)-vola_ser2(index,[4*ones(1,5)],:)].^2,1)./sum(index));
stat2(2,:,:)= sqrt(sum([log(vola_ser2(index,[1:3 5 6],:))-log(vola_ser2(index,[4*ones(1,5)],:))].^2,1)./sum(index));
stat2(3,:,:)= sum(abs([vola_ser2(index,[1:3 5 6],:)-vola_ser2(index,[4*ones(1,5)],:)])./(vola_ser2(index,[4*ones(1,5)],:)),1)./sum(index);
