function [predut,hthat,sq_hthat_mean,sq_sum_hthat,htcond,sq_htcond_mean,sq_sum_htcond] = filterswarchbetalev_bayes(y,Z,eta,alpha,gamma,xi,beta,steps);
% 
% function call: predut = filterswarchbetalev(y,lags,eta,alpha,gamma,xi,beta);
%
% INPUT:
% y     time series, (nx1) vector
% Z     time series, (nx number of variables)
% eta   fixed value transition matrix (kxk), rows must be probability vectors
% alpha  fixed values  (mx1)
% gamma  fixed values  for changing variances (kx1)
% xi     fixed value  for leverage parameter
% beta   fixed value for constant and lagged dep. variables
% steps  forcasting steps
%
% OUTPUT:
% simulated values:
% predut, prediction error
% hthat, steps-step ahead predicted ht (volatility squared)
% sq_hthat_mean, mean volatility over steps-step forecasting period
% sq_sum_hthat, square root of mean predicted ht (volatility squared) over steps-step
% 
% Authors: Sylvia Kaufmann

rand('state',1);
randn('state',1);

% number of states
nst=size(eta,1);

pini=ones(nst,1)/nst;
m=size(alpha,1);
nobs = size(y,1)+1;
states = [1:nst]';
[fvpred sp] = predfiltvertbetalev(y,Z,eta,pini,alpha,gamma,xi,beta);
yhat=Z*beta;
u=y-Z*beta;    

n=size(u,1);%lags=size(Z,2);
index=[];for i=1:m;index=[index;m-i+1:n-i];end;index=index';
U=u(index).^2;
dt=(u(m:end-1)<=0.0).*u(m:end-1).^2;
       
ht=gamma(:,ones(1,n-m))'+U*alpha(:,ones(1,nst))+dt*xi(ones(1,nst));
       
et=y-yhat; 
vt=et(end-size(ht,1)+1:end,ones(1,nst))./(ht.^0.5);
       
predut=(1+(erf(vt/sqrt(2))))/2;
       
predut=sum(predut.*fvpred(end-size(ht,1)+1:end,:),2);

hthat=fvpred(end-size(ht,1)+1:end,:)*gamma+U*alpha+dt*xi;
hthat_1step=hthat;
n=size(hthat,1);
fvpred=fvpred(end-size(ht,1)+1:end,:);
htlag=[U dt];
sq_hthat_mean=sqrt(hthat);
sum_hthat=hthat;

sst=sum([cumsum(fvpred,2) < kron(ones(1,nst),rand(n,1))],2)+1;
htcond=(sst(:,ones(1,nst))==states(:,ones(1,n))')*gamma+U*alpha+dt*xi;
htcond_1step=htcond;
htcond_lag=[U dt];
sq_htcond_mean=sqrt(htcond);
sum_htcond=htcond;


% y_abs=abs(y(1:end-steps+1));
% if steps>1;
%  for i=2:steps;
%     y_abs=y_abs+abs(y(i:end-steps+i));
%  end
%  y_abs=y_abs./steps
% end

for j=1:steps-1
    Uthat=sqrt(hthat).*randn(n,1);
    dt=Uthat<0;
    Uthat=Uthat.^2;
    htlag=[Uthat htlag(:,[1:end-2]) Uthat.*dt];
    hthat= fvpred*eta^j*gamma + htlag*[alpha;xi];
    sq_hthat_mean=sq_hthat_mean+sqrt(hthat);
    sum_hthat=sum_hthat+hthat;
    
    Utcond=sqrt(htcond).*randn(n,1);
    dct=Utcond<0;
    Utcond=Utcond.^2;
    htcond_lag=[Utcond htcond_lag(:,[1:end-2]) Utcond.*dct];
    sst=sum([cumsum(eta(sst,:),2) < kron(ones(1,nst),rand(n,1))],2)+1;
    htcond=(sst(:,ones(1,nst))==states(:,ones(1,n))')*gamma+htcond_lag*[alpha;xi];
    sq_htcond_mean=sq_htcond_mean+sqrt(htcond);
    sum_htcond=sum_htcond+htcond;
end


sq_hthat_mean=sq_hthat_mean./steps;
sq_sum_hthat=sqrt(sum_hthat./steps);
sq_htcond_mean=sq_htcond_mean./steps;
sq_sum_htcond=sqrt(sum_htcond./steps);

